@@ -256,15 +256,24 @@ class YandexParser(object):
         return int(max(pages))
 
     def get_current_region(self):
-        match = re.search(
-            r'<input type="?hidden"? name="lr" value="(\d+)"',
-            self.content,
-            flags=re.I | re.M
-        )
-        if not match:
-            raise YandexParserError(u'не удалось найти текущий регион')
+        patterns = [
+            re.compile(
+                r'<input type="?hidden"? name="lr" value="(\d+)"',
+                flags=re.I | re.M
+            ),
+            re.compile(
+                r'"lr":\s*(\d+)\s*',
+                flags=re.I | re.M
+            ),
+        ]
+
+        for pattern in patterns:
+            match = pattern.search(self.content)
+            if match:
+                return int(match.group(1))
+
+        raise YandexParserError(u'не удалось найти текущий регион')
 
-        return int(match.group(1))
 
     @classmethod
     def extract_mobile_page_content(self, content, page):
@@ -791,29 +800,47 @@ class YandexParser(object):
         if 'checkcaptcha' not in self.content:
             return
 
-        patterns = [
-            self.patterns['captcha'],
-            re.compile(u'<div class="captcha__image"><img\s*src=\"([^\"]+)\"'),
-        ]
+        captcha_type = None
+        form_method = None
+        if re.search(ur'>Я не робот<', self.content):
+            url_image = None
+            captcha_type = 'i_not_robot'
 
-        match_captcha = None
-        for pattern in patterns:
-            match_captcha = pattern.findall(self.content)
-            if match_captcha:
-                break
+            html = lxml.html.fromstring(self.content)
+            form = html.forms[0]
+            form_data = dict(form.form_values())
+            form_action = form.action
+            form_method = form.method
 
-        if not match_captcha:
-            raise YandexParserError()
-        url_image = match_captcha[0]
+        else:
+            patterns = [
+                self.patterns['captcha'],
+                re.compile(u'<div class="captcha__image"><img\s*src=\"([^\"]+)\"'),
+                re.compile(u'<img class="AdvancedCaptcha-Image"\s*src=\"([^\"]+)\"'),
+            ]
 
-        html = lxml.html.fromstring(self.content)
-        form = html.forms[0]
-        form_data = dict(form.form_values())
+            match_captcha = None
+            for pattern in patterns:
+                match_captcha = pattern.findall(self.content)
+                if match_captcha:
+                    break
+
+            if not match_captcha:
+                raise YandexParserError()
+            url_image = match_captcha[0]
+
+            html = lxml.html.fromstring(self.content)
+            form = html.forms[0]
+            form_data = dict(form.form_values())
+            form_action = form.action
+            form_method = form.method
 
         return {
+            'captcha_type': captcha_type,
             'url': url_image,
-            'form_action': form.action,
+            'form_action': form_action,
             'form_data': form_data,
+            'form_method': form_method,
         }
 
     @classmethod
